==> haskell-hunit-1.6.0.0-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: HUnit
version: 1.6.0.0
id: HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
key: HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
license: BSD-3-Clause
maintainer: Simon Hengel <sol@typeful.net>
author: Dean Herington
stability: stable
homepage: https://github.com/hspec/HUnit#readme
synopsis: A unit testing framework for Haskell
description:
    HUnit is a unit testing framework for Haskell, inspired by the
    JUnit tool for Java, see: <http://www.junit.org>.
category: Testing
abi: bbbaa73d864fa5ab08284bea74cc4e65
exposed: True
exposed-modules:
    Test.HUnit Test.HUnit.Base Test.HUnit.Lang Test.HUnit.Terminal
    Test.HUnit.Text
hidden-modules: Paths_HUnit
import-dirs: /usr/lib/ghc-8.6.5/site-local/HUnit-1.6.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/HUnit-1.6.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/HUnit-1.6.0.0
hs-libraries: HSHUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
depends:
    base-4.12.0.0 call-stack-0.1.0-J1eWgTNOnM4IGVyeW0v2YZ
    deepseq-1.4.4.0
haddock-interfaces: /usr/share/doc/haskell-hunit/html/HUnit.haddock
haddock-html: /usr/share/doc/haskell-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hunit-1.6.0.0-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: HUnit
version: 1.6.0.0
id: HUnit-1.6.0.0-CIh8yVnXF8fEfjQqWNmj9c
key: HUnit-1.6.0.0-CIh8yVnXF8fEfjQqWNmj9c
license: BSD-3-Clause
maintainer: Simon Hengel <sol@typeful.net>
author: Dean Herington
stability: stable
homepage: https://github.com/hspec/HUnit#readme
synopsis: A unit testing framework for Haskell
description:
    HUnit is a unit testing framework for Haskell, inspired by the
    JUnit tool for Java, see: <http://www.junit.org>.
category: Testing
abi: 5b09edb9af6b7aedcda66b56040816cb
exposed: True
exposed-modules:
    Test.HUnit Test.HUnit.Base Test.HUnit.Lang Test.HUnit.Terminal
    Test.HUnit.Text
hidden-modules: Paths_HUnit
import-dirs: /usr/lib/ghc-8.6.5/site-local/HUnit-1.6.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/HUnit-1.6.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/HUnit-1.6.0.0
hs-libraries: HSHUnit-1.6.0.0-CIh8yVnXF8fEfjQqWNmj9c
depends:
    base-4.12.0.0 call-stack-0.2.0-BFXF1vLNVFn5iwCyADehK4
    deepseq-1.4.4.0
haddock-interfaces: /usr/share/doc/haskell-hunit/html/HUnit.haddock
haddock-html: /usr/share/doc/haskell-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
